/* $Id: sm_pf.c,v 1.2 2005/10/18 19:58:12 dijkstra Exp $ */

#include <stdlib.h>

#include "sylimits.h"
#include "data.h"
#include "error.h"

void
privinit_pf()
{
    fatal("pf module not available");
}
void
init_pf(struct stream *st)
{
    fatal("pf module not available");
}
void
gets_pf()
{
    fatal("pf module not available");
}
int
get_pf(char *symon_buf, int maxlen, struct stream *st)
{
    fatal("pf module not available");

    /* NOT REACHED */
    return 0;
}
